﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using MindFusion.Charting;
using MindFusion.Charting.WinForms;
using MindFusion.Drawing;

using Color = System.Drawing.Color;


namespace MultipleAxes
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();		

			var plot = new Plot2D();
			plot.GridType = GridType.Horizontal;
			plot.GridLineStyle = System.Drawing.Drawing2D.DashStyle.Dash;

			// sample temperature data for bar graphics
			var barSeries = new Series2D(
				new List<double> { 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 },//x
				new List<double> { -3, -7, 10, 12, 20, 29, 33, 30, 24, 15, 2, -8 },//y
				new List<string> {
					"January", "February", "March", "April", "May", "June",
					"July", "August", "September", "October", "November", "December"})
				{
					Title = "Temperature"
				};
			barSeries.SupportedLabels = LabelKinds.XAxisLabel;

			// sample pressure data for line graphics
			var lineSeries = new Series2D(
				new List<double> { 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 },//x
				new List<double> { 100120, 101044, 101503, 103499, 102122, 100593, 
					95542, 102223, 103002, 102994, 102843, 101332},//right-y
				null)
				{
					Title = "Pressure"
				};

			// draw bars
			var barRenderer = new BarRenderer(
				new ObservableCollection<Series> { barSeries }
			);
			barRenderer.SeriesStyle = new UniformSeriesStyle(
				new LinearGradientBrush(Color.FromArgb(224, 233, 233), Color.FromArgb(0, 52, 102)),
				new SolidBrush(Color.FromArgb(97, 106, 127)),
				2.0, System.Drawing.Drawing2D.DashStyle.Solid);


			// draw lines
			var lineRenderer = new LineRenderer(
				new ObservableCollection<Series> { lineSeries }
			);
			lineRenderer.SeriesStyle = new UniformSeriesStyle(
				new SolidBrush(Color.FromArgb(102, 154, 204)),
				new SolidBrush(Color.FromArgb(102, 154, 204)), 4.0,
				System.Drawing.Drawing2D.DashStyle.Solid);

			// add graphics to plot
			plot.SeriesRenderers.Add(barRenderer);
			plot.SeriesRenderers.Add(lineRenderer);

			// draw annotations
			var annotations = new Series2D(
				new List<double> { 7 }, //x
				new List<double> { 95542 },//right-y
				new List<string> { "TORNADO" });
			var annotationRenderer = new AnnotationRenderer(
					new ObservableCollection<Series> { annotations });
			plot.SeriesRenderers.Add(annotationRenderer);
			

			// create axes
			var celsiusAxis = new Axis
			{
				Interval = 5,
				MinValue = -20,
				MaxValue = 50,
				Title = "Celsius"
			};

			var fahrenheitAxis = new Axis
			{
				MinValue = -20 * 1.8 + 32,
				MaxValue = 50 * 1.8 + 32,
				Interval = 10,
				Title = "Fahrenheit"
			};

			var kelvinAxis = new Axis
			{
				MinValue = -20 + 273.15,
				MaxValue = 50 + 273.15,
				Interval = 5,
				Title = "Kelvin"
			};

			var monthAxis = new Axis
			{
				Interval = 1,
				MinValue = 0,
				MaxValue = 12,
				Title = "Months"
			};

			var pascals = new Axis
			{
				MinValue = 90000,
				MaxValue = 106000,
				Interval = 1000,
				Title = "Pressure"
			};

			plot.YAxis = celsiusAxis;
			plot.XAxis = monthAxis;
			lineRenderer.YAxis = annotationRenderer.YAxis = pascals;

			// add legend
			dashboard1.RootPanel.Children.Add(new LegendRenderer()
			{
				Content = new System.Collections.ObjectModel.ObservableCollection<SeriesRenderer>
				{
					barRenderer, lineRenderer
				},
				Background = new SolidBrush(Color.FromArgb(250, 250, 250))
			});

			// create dashboard layout
			dashboard1.LayoutBuilder.CreateAndAddPlotAndAxes(
				plot, null,
				new YAxisRenderer[]
				{
					new YAxisRenderer(celsiusAxis),
					new YAxisRenderer(fahrenheitAxis),
					new YAxisRenderer(kelvinAxis)
				},
				new XAxisRenderer[] { new XAxisRenderer(monthAxis) { LabelsSource = plot } },
				new YAxisRenderer[] { new YAxisRenderer(pascals) });
		}

		
	}
}